within ;
package Meurs_e1
  connector bfc
    Real p(unit = "torr");
    flow Real q(unit = "ml/s");
    annotation(Icon(graphics={  Rectangle(origin = {-1, 0}, extent = {{-97, 98}, {97, -98}})}));
  end bfc;

  connector bfc_in
    extends Meurs_e1.bfc;
    annotation(Icon(graphics={  Rectangle(origin = {0, -1}, fillColor = {255, 255, 255},
              fillPattern =                                                                            FillPattern.Solid, extent = {{-98, 99}, {98, -99}})}));
  end bfc_in;

  connector bfc_out
    extends Meurs_e1.bfc;
    annotation(Icon(graphics={  Rectangle(origin = {-1, 0}, fillColor = {141, 0, 0},
              fillPattern =                                                                        FillPattern.Solid, extent = {{-99, 100}, {99, -100}})}));
  end bfc_out;

  model OnePort
    bfc_in In annotation(Placement(visible = true, transformation(origin = {-84, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    bfc_out Out annotation(Placement(visible = true, transformation(origin = {88, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Real q = In.q;
    Real dp = In.p - Out.p;
  equation
    In.q + Out.q = 0;
    annotation(Icon(graphics={  Rectangle(origin = {1, 0}, extent = {{-89, 82}, {89, -82}})}));
  end OnePort;

  model Resistor
    extends Meurs_e1.OnePort;
    parameter Real R;
  equation
    dp = R*q;
  annotation(Icon(graphics={  Rectangle(origin = {1, -1}, fillColor = {243, 16, 16},
              fillPattern =                                                                        FillPattern.Backward, extent = {{-85, 77}, {85, -77}})}));
  end Resistor;

  model ResistorVariable
    extends Meurs_e1.OnePort;
    Modelica.Blocks.Interfaces.RealInput R annotation(Placement(visible = true, transformation(origin = {-84, 74}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-80, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  equation
    dp = R*q;
  annotation(Icon(graphics={  Rectangle(origin = {0, -2}, fillColor = {229, 20, 20},
              fillPattern =                                                                        FillPattern.CrossDiag, extent = {{-82, 70}, {82, -70}})}));
  end ResistorVariable;

  model Inertance
    extends Meurs_e1.OnePort;
    Modelica.Blocks.Interfaces.RealInput L annotation(Placement(visible = true, transformation(origin = {-78, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-78, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  equation
    dp = der(q)*L;
  end Inertance;

  model ElasticCompartment

    bfc_in In annotation(Placement(visible = true, transformation(origin = {0, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput ExternalPressure annotation(Placement(visible = true, transformation(origin = {-8, 64}, extent = {{-32, -32}, {32, 32}}, rotation = 0), iconTransformation(origin = {4, 76}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput Elastance annotation(Placement(visible = true, transformation(origin = {-84, 66}, extent = {{-32, -32}, {32, 32}}, rotation = 0), iconTransformation(origin = {-72, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Volume(start = V0) annotation(Placement(visible = true, transformation(origin = {70, -76}, extent = {{-34, -34}, {34, 34}}, rotation = 0), iconTransformation(origin = {84, -86}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput StressedVolume annotation(Placement(visible = true, transformation(origin = {2, -72}, extent = {{-30, -30}, {30, 30}}, rotation = 0), iconTransformation(origin = {16, -86}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Pressure annotation(Placement(visible = true, transformation(origin = {-61, -69}, extent = {{-31, -31}, {31, 31}}, rotation = 0), iconTransformation(origin = {-46, -84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Real V0(unit = "ml")
      "initial volume if elastic compartment in ml";
    parameter Real UnstressedVolume(unit = "ml") "unstressed volume in ml";
    Real TransmuralPressure(unit = "mmHg");

  equation
    Pressure - ExternalPressure = TransmuralPressure;
    StressedVolume = Volume - UnstressedVolume;
    if StressedVolume > 0 then
      TransmuralPressure = Elastance * StressedVolume;
    else
      TransmuralPressure = 0;
    end if;

    der(Volume) = In.q;
    Pressure = In.p;

    annotation(Icon(graphics={  Ellipse(origin = {1, 0}, lineColor = {53, 49, 1}, fillColor = {255, 255, 255},
              fillPattern =                                                                                                  FillPattern.Sphere, extent = {{-97, 98}, {97, -98}}, endAngle = 360)}));
  end ElasticCompartment;

  model CardiacValve
    extends Meurs_e1.OnePort;

    Real s;
    Boolean open;
    parameter Real rOpen = 3e-3;
    parameter Real gClose = 0;
  equation
    open = s > 0;
    if open then
      dp = s * rOpen;
      s = q;
    else
      dp = s;
      q = s * gClose;
    end if;

    annotation(Icon(graphics={  Polygon(origin = {-25, 0}, fillColor = {255, 255, 0},
              fillPattern =                                                                         FillPattern.Solid,
              lineThickness =                                                                                                    1, points = {{-35, 0}, {-35, 60}, {25, 0}, {25, 60}, {35, 60}, {35, -60}, {25, -60}, {25, 0}, {-35, -60}, {-35, 0}})}));
  end CardiacValve;

  model HeartIntervals
    Modelica.Blocks.Interfaces.RealInput HR annotation(Placement(visible = true, transformation(origin = {-86, 58}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    discrete Modelica.Blocks.Interfaces.RealOutput Tas annotation(Placement(visible = true, transformation(origin = {102, 78}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    discrete Modelica.Blocks.Interfaces.RealOutput Tav annotation(Placement(visible = true, transformation(origin = {90, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    discrete Modelica.Blocks.Interfaces.RealOutput Tvs annotation(Placement(visible = true, transformation(origin = {88, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    discrete Modelica.Blocks.Interfaces.RealOutput T0 annotation(Placement(visible = true, transformation(origin = {90, -62}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));

    discrete Real HP;
    Boolean b;
  equation
    b = time - pre(T0) >= pre(HP);
    when {initial(), b} then
      T0 = time;
      HP = 60 / HR;
      Tas = 0.3 + 0.09 * HP;
      Tav = 0.01;
      Tvs = 0.16 + 0.2 * HP;
    end when;

    annotation(uses(Modelica(version = "3.2.1")), Icon(graphics={  Rectangle(origin = {-10, 0}, extent = {{-90, 100}, {90, -100}}), Text(origin = {-8, 83}, extent = {{-92, 17}, {88, -23}}, textString = "Heart Intervals"), Text(origin = {-60, 40}, lineColor = {0, 128, 255}, fillColor = {255, 255, 255}, extent = {{-20, 20}, {40, -20}}, textString = "HR"), Text(origin = {50, 40}, lineColor = {0, 128, 255}, extent = {{-30, 20}, {30, -20}}, textString = "Tas"), Text(origin = {50, 0}, lineColor = {0, 128, 255}, extent = {{-30, 20}, {30, -20}}, textString = "Tav"), Text(origin = {50, -40}, lineColor = {0, 128, 255}, extent = {{-30, 20}, {30, -20}}, textString = "Tvs"), Text(origin = {50, -80}, lineColor = {0, 128, 255}, extent = {{-30, 20}, {30, -20}}, textString = "T0")}));
  end HeartIntervals;

  model AtrialElastance
    Modelica.Blocks.Interfaces.RealInput Tas annotation(Placement(visible = true, transformation(origin = {-84, 58}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput T0 annotation(Placement(visible = true, transformation(origin = {-96, -62}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Et annotation(Placement(visible = true, transformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));

    parameter Real EMIN = 0.05;
    parameter Real EMAX = 0.15;

  equation
    if time > Tas - T0 then
      Et = EMIN + (EMAX - EMIN) * sin(Modelica.Constants.pi * (time - T0) / Tas);
    else
      Et = EMIN;
    end if;

    annotation(uses(Modelica(version = "3.2.1")), Icon(graphics={  Rectangle(origin = {-10, 0}, fillColor = {253, 253, 152},
              fillPattern =                                                                                                    FillPattern.Solid, extent = {{-90, 100}, {90, -100}}), Text(origin = {-10, 80}, lineColor = {0, 128, 255}, extent = {{90, 20}, {-90, -20}}, textString = "Atrial Elastance"), Text(origin = {-55, 39}, lineColor = {0, 128, 255}, extent = {{-23, 19}, {23, -19}}, textString = "Tas"), Text(origin = {-52, -62}, lineColor = {0, 128, 255}, extent = {{-24, 18}, {12, -16}}, textString = "T0"), Text(origin = {54, -3}, lineColor = {0, 128, 255}, extent = {{-22, 15}, {22, -15}}, textString = "Et")}));
  end AtrialElastance;

  model VentricularElastance
    Modelica.Blocks.Interfaces.RealInput Tas "duration of atrial systole" annotation(Placement(visible = true, transformation(origin = {-106, 72}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, 70}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput Tav "atrioventricular delay" annotation(Placement(visible = true, transformation(origin = {-112, 22}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput Tvs "duration of ventricular systole" annotation(Placement(visible = true, transformation(origin = {-98, -18}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, -30}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput T0 "time of start of cardiac cycle" annotation(Placement(visible = true, transformation(origin = {-104, -76}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Et "elasticity (torr/ml)" annotation(Placement(visible = true, transformation(origin = {88, 4}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));

    Real Et0 "normalised elasticity (mmHg/ml)";
    Real HeartInterval "time spended from the beginning of cardiac cycle";
    constant Real Kn = 0.57923032735652;
    parameter Real EMIN = 0 "Diastolic elastance (mmHg/ml)";
    parameter Real EMAX = 1 "Maximum systolic elastance (mmHg/ml)";

  equation
    HeartInterval = time - T0;
    Et = EMIN + (EMAX - EMIN) * Et0;
    if HeartInterval >= Tas + Tav and HeartInterval < Tas + Tav + Tvs then
      Et0 = (HeartInterval - (Tas + Tav)) / Tvs * sin(Modelica.Constants.pi * (HeartInterval - (Tas + Tav)) / Tvs) / Kn;
    else
      Et0 = 0;
    end if;

    annotation(uses(Modelica(version = "3.2.1")), Icon(graphics={  Rectangle(origin = {-10, 0}, fillColor = {253, 253, 152},
              fillPattern =                                                                                                    FillPattern.Solid, extent = {{-90, 100}, {90, -100}}), Text(origin = {2, 80}, lineColor = {0, 128, 255}, extent = {{-90, 20}, {70, 0}}, textString = "Ventricular Elastance"), Text(origin = {-58, 69}, lineColor = {0, 128, 255}, extent = {{-18, 11}, {18, -11}}, textString = "Tas"), Text(origin = {-54, 19}, lineColor = {0, 128, 255}, extent = {{-18, 11}, {18, -11}}, textString = "Tav"), Text(origin = {-54, -30}, lineColor = {0, 128, 255}, extent = {{-18, 10}, {18, -10}}, textString = "Tvs"), Text(origin = {-54, -79}, lineColor = {0, 128, 255}, extent = {{-16, 13}, {16, -13}}, textString = "T0"), Text(origin = {50, 1}, lineColor = {0, 128, 255}, extent = {{-22, 17}, {22, -17}}, textString = "Et")}));
  end VentricularElastance;

  model HeartPart
    Modelica.Blocks.Interfaces.RealInput ExtP annotation(Placement(visible = true, transformation(origin = {-100, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-80, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput HR annotation(Placement(visible = true, transformation(origin = {-100, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-80, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    HeartIntervals heartIntervals1 annotation(Placement(visible = true, transformation(origin = {-48, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    AtrialElastance atrialElastance annotation(Placement(visible = true, transformation(origin = {0, -54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    VentricularElastance ventricularElastance annotation(Placement(visible = true, transformation(origin = {0, -82}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    ElasticCompartment atrium annotation(Placement(visible = true, transformation(origin = {-44, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    ElasticCompartment ventricle annotation(Placement(visible = true, transformation(origin = {26, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    CardiacValve cardiacValve1 annotation(Placement(visible = true, transformation(origin = {56, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    CardiacValve cardiacValve2 annotation(Placement(visible = true, transformation(origin = {-8, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(atrium.ExternalPressure, ExtP) annotation(Line(points={{-43.6,7.6},
            {-43.6,7.6},{-43.6,80},{-100,80}},                                                                               color = {0, 0, 127}));
    connect(ExtP, ventricle.ExternalPressure) annotation(Line(points={{-100,80},
            {26,80},{26,7.6},{26.4,7.6}},                                                                        color = {0, 0, 127}));
    connect(ventricularElastance.Et, ventricle.Elastance) annotation(Line(points={{9,-82},
            {14,-82},{14,8},{18.8,8},{18.8,7.8}},                                                                                     color = {0, 0, 127}));
    connect(atrialElastance.Et, atrium.Elastance) annotation(Line(points={{9,-54},
            {12,-54},{12,20},{-58,20},{-58,8},{-51.2,8},{-51.2,7.8}},                                                                                 color = {0, 0, 127}));
    connect(cardiacValve2.In, atrium.In) annotation(Line(points={{-17,0},{-30,0},
            {-30,0.2},{-44,0.2}}));
    connect(cardiacValve2.Out, ventricle.In) annotation(Line(points={{1,-0.2},{
            8,-0.2},{8,0},{14,0},{14,0.2},{26,0.2}}));
    connect(cardiacValve1.In, ventricle.In) annotation(Line(points={{47,0},{26,
            0},{26,0.2},{26,0.2}}));
    connect(cardiacValve1.Out, bfc_out1) annotation(Line(points={{65,-0.2},{88,
            -0.2},{88,-2},{90,-2}}));
    connect(bfc_in1, atrium.In) annotation(Line(points={{-90,0},{-44,0},{-44,
            0.2}}));
    connect(atrialElastance.T0, heartIntervals1.T0) annotation(Line(points={{-10,-60},
            {-36,-60},{-36,-74},{-38,-74},{-38,-74},{-39,-74}},                                                                                        color = {0, 0, 127}));
    connect(heartIntervals1.T0, ventricularElastance.T0) annotation(Line(points={{-39,-74},
            {-36,-74},{-36,-90},{-12,-90},{-12,-90},{-10,-90}},                                                                                             color = {0, 0, 127}));
    connect(ventricularElastance.Tvs, heartIntervals1.Tvs) annotation(Line(points={{-10,-85},
            {-34,-85},{-34,-70},{-38,-70},{-38,-70},{-39,-70}},                                                                                               color = {0, 0, 127}));
    connect(ventricularElastance.Tav, heartIntervals1.Tav) annotation(Line(points={{-10,-80},
            {-30,-80},{-30,-66},{-39,-66}},                                                                                           color = {0, 0, 127}));
    connect(heartIntervals1.Tas, atrialElastance.Tas) annotation(Line(points={{-39,-62},
            {-28,-62},{-28,-50},{-10,-50}},                                                                                      color = {0, 0, 127}));
    connect(ventricularElastance.Tas, heartIntervals1.Tas) annotation(Line(points={{-10,-75},
            {-28,-75},{-28,-62},{-39,-62}},                                                                                           color = {0, 0, 127}));
    connect(HR, heartIntervals1.HR) annotation(Line(points = {{-100, -80}, {-70, -80}, {-70, -62}, {-58, -62}, {-58, -62}}, color = {0, 0, 127}));
    annotation(uses(Modelica(version = "3.2.1")), Icon(graphics={  Rectangle(lineColor = {60, 188, 41}, fillColor = {59, 188, 35},
              fillPattern =                                                                                                    FillPattern.Solid, extent = {{-60, 10}, {60, -10}}), Text(origin = {-2, -60}, lineColor = {60, 188, 41}, extent = {{-50, 40}, {50, -40}}, textString = "2"), Text(origin = {11, 40}, lineColor = {60, 188, 41}, extent = {{-69, 30}, {49, -30}}, textString = "Heart"), Text(origin = {13, 83}, lineColor = {60, 188, 41}, extent = {{-73, 17}, {87, -23}}, textString = "%name")}, coordinateSystem(initialScale = 0.1)));
  end HeartPart;

  model ArteryPart
    bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealInput IntrathoraticPressure annotation(Placement(visible = true, transformation(origin = {-100, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  ElasticCompartment IntrathoracticArteries(UnstressedVolume = 140, V0 = 201) annotation(Placement(visible = true, transformation(origin = {-44, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Inertance inertance1 annotation(Placement(visible = true, transformation(origin = {-14, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Resistor ExtrathoraticArterialResistance(R = 0.06)  annotation(Placement(visible = true, transformation(origin = {22, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  ElasticCompartment elasticCompartment2(UnstressedVolume = 370, V0 = 519)  annotation(Placement(visible = true, transformation(origin = {56, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const(k = 1.41)  annotation(Placement(visible = true, transformation(origin = {-76, 38}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const1(k = 0.0007)  annotation(Placement(visible = true, transformation(origin = {-30, 44}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const2(k = 0.556)  annotation(Placement(visible = true, transformation(origin = {18, 46}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const3(k = 0)  annotation(Placement(visible = true, transformation(origin = {60, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(const.y, IntrathoracticArteries.Elastance) annotation(Line(points = {{-64, 38}, {-51, 38}, {-51, 8}}, color = {0, 0, 127}));
    connect(IntrathoraticPressure, IntrathoracticArteries.ExternalPressure) annotation(Line(points = {{-100, 80}, {-44, 80}, {-44, 8}}, color = {0, 0, 127}));
    connect(IntrathoracticArteries.In, inertance1.In) annotation(Line(points = {{-44, 0}, {-23, 0}}));
    connect(bfc_in1, IntrathoracticArteries.In) annotation(Line(points = {{-90, 0}, {-44, 0}}));
    connect(const3.y, elasticCompartment2.ExternalPressure) annotation(Line(points = {{72, 50}, {76, 50}, {76, 18}, {56, 18}, {56, 8}, {56, 8}}, color = {0, 0, 127}));
    connect(const2.y, elasticCompartment2.Elastance) annotation(Line(points = {{30, 46}, {36, 46}, {36, 8}, {48, 8}, {48, 8}}, color = {0, 0, 127}));
    connect(const1.y, inertance1.L) annotation(Line(points = {{-18, 44}, {-14, 44}, {-14, 16}, {-30, 16}, {-30, 8}, {-22, 8}, {-22, 8}}, color = {0, 0, 127}));
    connect(inertance1.Out, ExtrathoraticArterialResistance.In) annotation(Line(points = {{-5, 0}, {12, 0}}));
    connect(bfc_out1, elasticCompartment2.In) annotation(Line(points = {{90, 0}, {56, 0}, {56, 0}, {56, 0}}));
    connect(ExtrathoraticArterialResistance.Out, elasticCompartment2.In) annotation(Line(points = {{32, 0}, {56, 0}, {56, 0}, {56, 0}}));
    annotation(uses(Modelica(version = "3.2.1")), Icon(graphics={  Text(lineColor = {255, 0, 0}, extent = {{-80, 60}, {80, -60}}, textString = "Artery")}));
  end ArteryPart;

  model TissuePart
    bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Resistor SystemicArteriolarResistance(R = 0.8)  annotation(Placement(visible = true, transformation(origin = {-52, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  ElasticCompartment SystemicTissues(UnstressedVolume = 185, V0 = 281)  annotation(Placement(visible = true, transformation(origin = {0, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Resistor SmallVenuleResistance(R = 0.2) annotation(Placement(visible = true, transformation(origin = {52, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const(k = 0.262)  annotation(Placement(visible = true, transformation(origin = {-76, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const1(k = 0)  annotation(Placement(visible = true, transformation(origin = {-36, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(SmallVenuleResistance.Out, bfc_out1) annotation(Line(points = {{62, 0}, {90, 0}}));
    connect(const1.y, SystemicTissues.ExternalPressure) annotation(Line(points = {{-24, 54}, {0, 54}, {0, 38}, {0, 38}}, color = {0, 0, 127}));
    connect(const.y, SystemicTissues.Elastance) annotation(Line(points = {{-64, 54}, {-58, 54}, {-58, 38}, {-8, 38}, {-8, 38}}, color = {0, 0, 127}));
    connect(SystemicTissues.In, SmallVenuleResistance.In) annotation(Line(points = {{0, 30}, {30, 30}, {30, 0}, {42, 0}, {42, 0}}));
    connect(SystemicArteriolarResistance.Out, SystemicTissues.In) annotation(Line(points = {{-42, 0}, {-20, 0}, {-20, 30}, {0, 30}, {0, 30}}));
    connect(bfc_in1, SystemicArteriolarResistance.In) annotation(Line(points = {{-90, 0}, {-62, 0}, {-62, 0}, {-62, 0}}));
    annotation(Icon(graphics={  Text(lineColor = {255, 102, 255}, extent = {{-80, 80}, {80, -80}}, textString = "Tissue")}), uses(Modelica(version = "3.2.1")));
  end TissuePart;

  model VeinPart
    bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  ElasticCompartment ExtrathoracicVeins(UnstressedVolume = 1000, V0 = 1546) annotation(Placement(visible = true, transformation(origin = {-58, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Resistor VenousResistance(R = 0.09) annotation(Placement(visible = true, transformation(origin = {-26, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  ElasticCompartment elasticCompartment2(UnstressedVolume = 1190, V0 = 1523)  annotation(Placement(visible = true, transformation(origin = {20, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Resistor CentralVenousResistance(R = 0.003)  annotation(Placement(visible = true, transformation(origin = {56, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealInput u annotation(Placement(visible = true, transformation(origin = {-100, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const(k = 0.0169)  annotation(Placement(visible = true, transformation(origin = {-88, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const1(k = 0)  annotation(Placement(visible = true, transformation(origin = {-54, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const2(k = 0.0182)  annotation(Placement(visible = true, transformation(origin = {-16, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(const1.y, ExtrathoracicVeins.ExternalPressure) annotation(Line(points = {{-42, 54}, {-42, 16}, {-58, 16}, {-58, 8}}, color = {0, 0, 127}));
    connect(const.y, ExtrathoracicVeins.Elastance) annotation(Line(points = {{-76, 54}, {-65, 54}, {-65, 8}}, color = {0, 0, 127}));
    connect(ExtrathoracicVeins.In, VenousResistance.In) annotation(Line(points = {{-58, 0}, {-36, 0}}));
    connect(bfc_in1, ExtrathoracicVeins.In) annotation(Line(points = {{-90, 0}, {-58, 0}}));
    connect(const2.y, elasticCompartment2.Elastance) annotation(Line(points = {{-4, 54}, {12, 54}, {12, 8}, {12, 8}}, color = {0, 0, 127}));
    connect(u, elasticCompartment2.ExternalPressure) annotation(Line(points = {{-100, 80}, {20, 80}, {20, 8}, {20, 8}}, color = {0, 0, 127}));
    connect(CentralVenousResistance.Out, bfc_out1) annotation(Line(points = {{66, 0}, {88, 0}, {88, 0}, {90, 0}}));
    connect(elasticCompartment2.In, CentralVenousResistance.In) annotation(Line(points = {{20, 0}, {46, 0}, {46, 0}, {46, 0}}));
    connect(VenousResistance.Out, elasticCompartment2.In) annotation(Line(points = {{-16, 0}, {20, 0}, {20, 0}, {20, 0}}));
    annotation(Icon(graphics={  Text(lineColor = {0, 0, 255}, extent = {{-80, 80}, {80, -80}}, textString = "Veins")}), uses(Modelica(version = "3.2.1")));
  end VeinPart;

  model PulmonaryPart
    bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealInput IntrathoraticPressure annotation(Placement(visible = true, transformation(origin = {-100, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  ElasticCompartment PulmonaryArteries(UnstressedVolume = 50, V0 = 103)  annotation(Placement(visible = true, transformation(origin = {-60, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Resistor PulmonaryResistance(R = 0.11)  annotation(Placement(visible = true, transformation(origin = {-30, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  ElasticCompartment PulmonaryVeins(UnstressedVolume = 350, V0 = 508)  annotation(Placement(visible = true, transformation(origin = {20, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Resistor PulmonaryVenousResistance(R = 0.003)  annotation(Placement(visible = true, transformation(origin = {52, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const(k = 0.233)  annotation(Placement(visible = true, transformation(origin = {-90, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const1(k = 0.0455)  annotation(Placement(visible = true, transformation(origin = {-30, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(const1.y, PulmonaryVeins.Elastance) annotation(Line(points = {{-18, 40}, {12, 40}, {12, 8}, {12, 8}}, color = {0, 0, 127}));
    connect(const.y, PulmonaryArteries.Elastance) annotation(Line(points = {{-78, 40}, {-68, 40}, {-68, 8}, {-68, 8}}, color = {0, 0, 127}));
    connect(IntrathoraticPressure, PulmonaryVeins.ExternalPressure) annotation(Line(points = {{-100, 80}, {20, 80}, {20, 8}, {20, 8}}, color = {0, 0, 127}));
    connect(IntrathoraticPressure, PulmonaryArteries.ExternalPressure) annotation(Line(points = {{-100, 80}, {-60, 80}, {-60, 8}, {-60, 8}}, color = {0, 0, 127}));
    connect(PulmonaryVenousResistance.Out, bfc_out1) annotation(Line(points = {{62, 0}, {88, 0}, {88, 0}, {90, 0}}));
    connect(PulmonaryVeins.In, PulmonaryVenousResistance.In) annotation(Line(points = {{20, 0}, {42, 0}, {42, 0}, {42, 0}}));
    connect(PulmonaryResistance.Out, PulmonaryVeins.In) annotation(Line(points = {{-20, 0}, {20, 0}, {20, 0}, {20, 0}}));
    connect(PulmonaryArteries.In, PulmonaryResistance.In) annotation(Line(points = {{-60, 0}, {-40, 0}, {-40, 0}, {-40, 0}}));
    connect(bfc_in1, PulmonaryArteries.In) annotation(Line(points = {{-90, 0}, {-60, 0}, {-60, 0}, {-60, 0}}));
    annotation(uses(Modelica(version = "3.2.1")), Icon(graphics={  Text(origin = {0, 4}, lineColor = {102, 102, 255}, extent = {{-80, 70}, {80, -70}}, textString = "Pulmonary")}));
  end PulmonaryPart;

  model VanMeurs

    HeartPart RightHeart(atrialElastance(EMIN=0.05, EMAX=0.06), ventricularElastance(EMIN=0.057, EMAX=0.49), atrium(V0=149, UnstressedVolume=30), ventricle(V0=143, UnstressedVolume=40)) annotation(Placement(visible = true, transformation(origin = {-52, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    HeartPart LeftHeart(atrialElastance(EMIN=0.12, EMAX=0.28), ventricularElastance(EMIN=0.09, EMAX=4), atrium(V0=89, UnstressedVolume=30), ventricle(V0=138, UnstressedVolume=60)) annotation(Placement(visible = true, transformation(origin = {50, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    PulmonaryPart pulmonaryPart1 annotation(Placement(visible = true, transformation(origin = {-2, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    ArteryPart arteryPart1 annotation(Placement(visible = true, transformation(origin = {68, -26}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    TissuePart tissuePart1 annotation(Placement(visible = true, transformation(origin = {0, -26}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    VeinPart veinPart1 annotation(Placement(visible = true, transformation(origin = {-54, -26}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant HeartRate(k = 72)  annotation(Placement(visible = true, transformation(origin = {-8, -72}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant IntrathoraticPressure(k = -4)  annotation(Placement(visible = true, transformation(origin = {-22, 32}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(veinPart1.u, IntrathoraticPressure.y) annotation(Line(points={{-44,-18},
            {0,-18},{0,32},{-11,32}},                                                                                             color = {0, 0, 127}));
    connect(arteryPart1.IntrathoraticPressure, IntrathoraticPressure.y) annotation(Line(points={{78,-18},
            {0,-18},{0,32},{-11,32}},                                                                                                    color = {0, 0, 127}));
    connect(LeftHeart.ExtP, IntrathoraticPressure.y) annotation(Line(points={{42,68},
            {16,68},{16,32},{-11,32}},                                                                                              color = {0, 0, 127}));
    connect(IntrathoraticPressure.y, pulmonaryPart1.IntrathoraticPressure) annotation(Line(points={{-11,32},
            {16,32},{16,88},{-12,88}},                                                                                                    color = {0, 0, 127}));
    connect(IntrathoraticPressure.y, RightHeart.ExtP) annotation(Line(points={{-11,32},
            {0,32},{0,74},{-60,74},{-60,68}},                                                                                                  color = {0, 0, 127}));
    connect(RightHeart.HR, HeartRate.y) annotation(Line(points={{-60,52},{-76,
            52},{-76,-44},{14,-44},{14,-72},{3,-72}},                                                                                          color = {0, 0, 127}));
    connect(HeartRate.y, LeftHeart.HR) annotation(Line(points={{3,-72},{30,-72},
            {30,52},{42,52}},                                                                                        color = {0, 0, 127}));
    connect(veinPart1.bfc_out1, RightHeart.bfc_in1) annotation(Line(points={{-63,-26},
            {-86,-26},{-86,60},{-62,60},{-61,60}}));
    connect(tissuePart1.bfc_out1, veinPart1.bfc_in1) annotation(Line(points={{-9,-26},
            {-44,-26},{-44,-26},{-45,-26}}));
    connect(arteryPart1.bfc_out1, tissuePart1.bfc_in1) annotation(Line(points={{59,-26},
            {10,-26},{10,-26},{9,-26}}));
    connect(LeftHeart.bfc_out1, arteryPart1.bfc_in1) annotation(Line(points={{59,60},
            {88,60},{88,-26},{77,-26}}));
    connect(pulmonaryPart1.bfc_in1, RightHeart.bfc_out1) annotation(Line(points={{-11,80},
            {-36,80},{-36,60},{-43,60}}));
    connect(pulmonaryPart1.bfc_out1, LeftHeart.bfc_in1) annotation(Line(points={{7,80},{
            32,80},{32,60},{41,60}}));
  annotation(uses(Modelica(version = "3.2.1")), Diagram(coordinateSystem(
            preserveAspectRatio=false, extent={{-100,-100},{100,100}})));
  end VanMeurs;
  annotation(uses(Modelica(version="3.2.1")));
end Meurs_e1;
